@@ -25,7 +25,7 @@
 
 
 /*
- * $Id: cweight.c,v 1.2 2001/06/12 13:14:23 thep Exp $
+ * $Id: cweight.c,v 1.3 2001-08-14 06:11:41 thep Exp $
  * cweight.c - Thai Character Weight Table for TIS-620/2533 Collating
  * Created: 9 Nov 1998
  * Author:  Theppitak Karoonboonyanan <thep@links.nectec.or.th>
@@ -141,7 +141,7 @@ enum l1_symbols {
     L1_SARA_AE,
     L1_SARA_O,
     L1_SARA_AI_MAIMUAN,
-    L1_SARA_AI_MAIMALAI,
+    L1_SARA_AI_MAIMALAI
 };
   
 /* level 2 symbols & order */
@@ -155,7 +155,7 @@ enum l2_symbols {
     L2_TONE1,
     L2_TONE2,
     L2_TONE3,
-    L2_TONE4,
+    L2_TONE4
 };
   
 /* level 3 symbols & order */
@@ -200,7 +200,7 @@ enum l3_symbols {
     L3_LESS_THAN,
     L3_EQUAL,
     L3_GREATER_THAN,
-    L3_V_LINE,
+    L3_V_LINE
 };
 
 /* level 4 symbols & order */
@@ -208,7 +208,7 @@ enum l4_symbols {
     L4_BLK = TOT_LEVELS,
     L4_MIN,
     L4_CAP,
-    L4_EXT,
+    L4_EXT
 };
 
 
