@@ -1,7 +1,9 @@
 /*
- * $Id: thwchar.c,v 1.3 2001/07/31 15:01:54 thep Exp $
+ * $Id: thwchar.c,v 1.7 2001-09-14 14:05:09 thep Exp $
  * thwchar.c - wide char support for Thai
  * Created: 2001-07-27
+ * Author:  Pattara Kiatisevi <ott@linux.thai.net>,
+ *          Theppitak Karoonboonyanan <thep@links.nectec.or.th>
  */
 
 #include <thai/thwchar.h>
@@ -9,7 +11,7 @@
 #define WC_ERR THWCHAR_ERR
 #define TH_ERR THCHAR_ERR
 
-static thwchar_t tis620_0_uni_map[128] = {
+static thwchar_t tis620_0_uni_map_[128] = {
     WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, 
     WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, 
     WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, WC_ERR, 
@@ -28,7 +30,7 @@ static thwchar_t tis620_0_uni_map[128] = {
     0x0e58, 0x0e59, 0x0e5a, 0x0e5b, WC_ERR, WC_ERR, WC_ERR, WC_ERR
 };
 
-static thchar_t uni_tis620_0_map[96] = {
+static thchar_t uni_tis620_0_map_[96] = {
   TH_ERR,    0xa1,   0xa2,   0xa3,   0xa4,   0xa5,   0xa6,   0xa7,
     0xa8,    0xa9,   0xaa,   0xab,   0xac,   0xad,   0xae,   0xaf,
     0xb0,    0xb1,   0xb2,   0xb3,   0xb4,   0xb5,   0xb6,   0xb7,
@@ -43,7 +45,7 @@ static thchar_t uni_tis620_0_map[96] = {
     0xf8,    0xf9,   0xfa,   0xfb, TH_ERR, TH_ERR, TH_ERR, TH_ERR
 };
 
-static thwchar_t tis620_1_uni_map[128] = {
+static thwchar_t tis620_1_uni_map_[128] = {
     0x00ab, 0x00bb, 0x2026, 0xf88c, 0xf88f, 0xf892, 0xf895, 0xf898,
     0xf88b, 0xf88e, 0xf891, 0xf894, 0xf897, 0x201c, 0x201d, 0xf899,
     WC_ERR, 0x2022, 0xf884, 0xf889, 0xf885, 0xf886, 0xf887, 0xf888,
@@ -62,7 +64,7 @@ static thwchar_t tis620_1_uni_map[128] = {
     0x0e58, 0x0e59, 0x00ae, 0x00a9, WC_ERR, WC_ERR, WC_ERR, WC_ERR
 };
 
-static thwchar_t tis620_2_uni_map[128] = {
+static thwchar_t tis620_2_uni_map_[128] = {
     0xf700, 0xf701, 0xf702, 0xf703, 0xf704, 0x2026, 0xf705, 0xf706,
     0xf707, 0xf708, 0xf709, 0xf70a, 0xf70b, 0xf70c, 0xf70d, 0xf70e,
     0xf70f, 0x2018, 0x2019, 0x201c, 0x201d, 0x2022, 0x2013, 0x2014,
@@ -83,7 +85,7 @@ static thwchar_t tis620_2_uni_map[128] = {
 
 thwchar_t th_tis2uni(thchar_t c)
 {
-    return (c < 0x80) ? (thwchar_t)c : tis620_0_uni_map[c-0x80];
+    return (c < 0x80) ? (thwchar_t)c : tis620_0_uni_map_[c-0x80];
 }
 
 int th_tis2uni_line(const thchar_t *s, thwchar_t result[], size_t n)
@@ -99,12 +101,12 @@ int th_tis2uni_line(const thchar_t *s, thwchar_t result[], size_t n)
 
 thwchar_t th_winthai2uni(thchar_t c)
 {
-    return (c < 0x80) ? (thwchar_t)c : tis620_2_uni_map[c-0x80];
+    return (c < 0x80) ? (thwchar_t)c : tis620_2_uni_map_[c-0x80];
 }
 
 thwchar_t th_macthai2uni(thchar_t c)
 {
-    return (c < 0x80) ? (thwchar_t)c : tis620_1_uni_map[c-0x80];
+    return (c < 0x80) ? (thwchar_t)c : tis620_1_uni_map_[c-0x80];
 }
 
 
@@ -115,7 +117,7 @@ thchar_t th_uni2tis(thwchar_t c)
         return (thchar_t) c ;
     } else if (0x0e00 <= c && c <= 0x0e5f) {
         /* THAI range */
-        return uni_tis620_0_map[c-0x0e00];
+        return uni_tis620_0_map_[c-0x0e00];
     } else {
         /* out of range */
         return TH_ERR;
@@ -133,15 +135,26 @@ int th_uni2tis_line(const thwchar_t *s, thchar_t result[], size_t n)
     return n - left;
 }
 
-thchar_t th_uni2winthai(thwchar_t c)
+
+static thchar_t uni2thai_ext_(thwchar_t wc, const thwchar_t rev_map[])
 {
-    /* FIXME */
-    return 0;
+    /* wc assumed out of TIS range */
+    thchar_t c = 0x80;
+    do {
+        if (rev_map[c-0x80] == wc) return c;
+    } while (c++ <= 0xff);
+    return TH_ERR;
 }
 
-thchar_t th_uni2macthai(thwchar_t c)
+thchar_t th_uni2winthai(thwchar_t wc)
 {
-    /* FIXME */
-    return 0;
+    thchar_t c = th_uni2tis(wc);
+    return (c == TH_ERR) ? uni2thai_ext_(wc, tis620_2_uni_map_) : c;
+}
+
+thchar_t th_uni2macthai(thwchar_t wc)
+{
+    thchar_t c = th_uni2tis(wc);
+    return (c == TH_ERR) ? uni2thai_ext_(wc, tis620_1_uni_map_) : c;
 }
 
